Documentation
¶
Overview ¶
Package auth provides authentication-related functionality for the application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Handler ¶
type Handler interface {
Create() gin.HandlerFunc
GetToken() gin.HandlerFunc
// contains filtered or unexported methods
}
Handler interface defines the methods that should be implemented by the auth handler.
func NewHandler ¶ added in v1.5.0
NewHandler creates and returns a new Handler instance.
Parameters:
- appCtx: *http.Context - The application context.
Returns:
- Handler: A new Handler instance.
type StoreAppRepData ¶
StoreAppRepData defines the structure for the response data when storing an app.
type StoreAppReqParams ¶
type StoreAppReqParams struct {
AppName string `json:"app_name" form:"app_name" binding:"required"`
Description string `json:"description" form:"description"`
RedirectUri string `json:"redirect_uri" form:"redirect_uri"`
}
StoreAppReqParams defines the structure for storing app request parameters.
Click to show internal directories.
Click to hide internal directories.